@@ -22,9 +22,6 @@ from apigee.utils import (extract_zip, resolve_target_directory, touch,
 
 
 class Backups:
-
-    SNAPSHOTS_DIRECTORY_NAME = 'snapshots'
-
     def __init__(
         self,
         auth,
@@ -49,10 +46,6 @@ class Backups:
         self.progress_bar = None
         self.org_path = Path(self.target_directory) / self.org_name
 
-    # def __del__(self):
-    #     if isinstance(self.progress_bar, tqdm):
-    #         self.progress_bar.close()
-
     @property
     def apis(self):
         return self._apis
@@ -78,14 +71,10 @@ class Backups:
             self.progress_bar.set_description(desc)
         self.progress_bar.update(1)
 
-    def _gen_snapshot_path(self, subpaths=[]):
-        path = self.org_path / self.SNAPSHOTS_DIRECTORY_NAME
-        for subpath in subpaths:
-            path /= subpath
-        return str(path)
-
-    def _gen_download_path(self, subpaths=[]):
+    def _gen_download_path(self, is_snapshot=False, subpaths=[]):
         path = self.org_path
+        if is_snapshot:
+            path /= 'snapshots'
         for subpath in subpaths:
             path /= subpath
         return str(path)
@@ -97,17 +86,11 @@ class Backups:
             self.snapshot_data.apis[api] = (
                 Apis(self.auth, self.org_name, None).get_api_proxy(api).json()
             )
-            data = {
-                'snapshot': self.snapshot_data.apis[api],
-                'target_path': self._gen_snapshot_path(subpaths=['apis', f'{api}.json']),
-                'fs_write': self.fs_write,
-                'indent': 2,
-            }
             write_file(
-                data['snapshot'],
-                data['target_path'],
-                fs_write=data['fs_write'],
-                indent=data['indent'],
+                self.snapshot_data.apis[api],
+                self._gen_download_path(is_snapshot=True, subpaths=['apis', f'{api}.json']),
+                fs_write=self.fs_write,
+                indent=2,
             )
         return self.snapshot_data.apis
 
@@ -141,19 +124,13 @@ class Backups:
                 )
             except HTTPError:
                 self.snapshot_data.keyvaluemaps[environment] = []
-            data = {
-                'snapshot': self.snapshot_data.keyvaluemaps[environment],
-                'target_path': self._gen_snapshot_path(
-                    subpaths=['keyvaluemaps', environment, 'keyvaluemaps.json']
-                ),
-                'fs_write': self.fs_write,
-                'indent': 2,
-            }
             write_file(
-                data['snapshot'],
-                data['target_path'],
-                fs_write=data['fs_write'],
-                indent=data['indent'],
+                self.snapshot_data.keyvaluemaps[environment],
+                self._gen_download_path(
+                    is_snapshot=True, subpaths=['keyvaluemaps', environment, 'keyvaluemaps.json']
+                ),
+                fs_write=self.fs_write,
+                indent=2,
             )
         return self.snapshot_data.keyvaluemaps
 
@@ -161,16 +138,15 @@ class Backups:
         for environment in self.environments:
             for kvm in self.snapshot_data.keyvaluemaps[environment]:
                 try:
-                    data = {
-                        'snapshot': Keyvaluemaps(self.auth, self.org_name, kvm)
+                    write_file(
+                        Keyvaluemaps(self.auth, self.org_name, kvm)
                         .get_keyvaluemap_in_an_environment(environment)
                         .text,
-                        'target_path': self._gen_download_path(
+                        self._gen_download_path(
                             subpaths=['keyvaluemaps', environment, f'{kvm}.json']
                         ),
-                        'fs_write': self.fs_write,
-                    }
-                    write_file(data['snapshot'], data['target_path'], fs_write=data['fs_write'])
+                        fs_write=self.fs_write,
+                    )
                 except HTTPError as e:
                     console.echo(
                         f'Ignoring {type(e).__name__} {e.response.status_code} error for KVM ({kvm})'
@@ -188,19 +164,13 @@ class Backups:
                 )
             except HTTPError:
                 self.snapshot_data.targetservers[environment] = []
-            data = {
-                'snapshot': self.snapshot_data.targetservers[environment],
-                'target_path': self._gen_snapshot_path(
-                    subpaths=['targetservers', environment, 'targetservers.json']
-                ),
-                'fs_write': self.fs_write,
-                'indent': 2,
-            }
             write_file(
-                data['snapshot'],
-                data['target_path'],
-                fs_write=data['fs_write'],
-                indent=data['indent'],
+                self.snapshot_data.targetservers[environment],
+                self._gen_download_path(
+                    is_snapshot=True, subpaths=['targetservers', environment, 'targetservers.json']
+                ),
+                fs_write=self.fs_write,
+                indent=2,
             )
         return self.snapshot_data.targetservers
 
@@ -208,16 +178,15 @@ class Backups:
         for environment in self.environments:
             for targetserver in self.snapshot_data.targetservers[environment]:
                 try:
-                    data = {
-                        'snapshot': Targetservers(self.auth, self.org_name, targetserver)
+                    write_file(
+                        Targetservers(self.auth, self.org_name, targetserver)
                         .get_targetserver(environment)
                         .text,
-                        'target_path': self._gen_download_path(
+                        self._gen_download_path(
                             subpaths=['targetservers', environment, f'{targetserver}.json']
                         ),
-                        'fs_write': self.fs_write,
-                    }
-                    write_file(data['snapshot'], data['target_path'], fs_write=data['fs_write'])
+                        fs_write=self.fs_write,
+                    )
                 except HTTPError as e:
                     console.echo(
                         f'Ignoring {type(e).__name__} {e.response.status_code} error for TargetServer ({targetserver})'
@@ -233,19 +202,13 @@ class Backups:
                 ).list_caches_in_an_environment(environment, prefix=self.prefix, format='dict')
             except HTTPError:
                 self.snapshot_data.caches[environment] = []
-            data = {
-                'snapshot': self.snapshot_data.caches[environment],
-                'target_path': self._gen_snapshot_path(
-                    subpaths=['caches', environment, 'caches.json']
-                ),
-                'fs_write': self.fs_write,
-                'indent': 2,
-            }
             write_file(
-                data['snapshot'],
-                data['target_path'],
-                fs_write=data['fs_write'],
-                indent=data['indent'],
+                self.snapshot_data.caches[environment],
+                self._gen_download_path(
+                    is_snapshot=True, subpaths=['caches', environment, 'caches.json']
+                ),
+                fs_write=self.fs_write,
+                indent=2,
             )
         return self.snapshot_data.caches
 
@@ -253,16 +216,13 @@ class Backups:
         for environment in self.environments:
             for cache in self.snapshot_data.caches[environment]:
                 try:
-                    data = {
-                        'snapshot': Caches(self.auth, self.org_name, cache)
+                    write_file(
+                        Caches(self.auth, self.org_name, cache)
                         .get_information_about_a_cache(environment)
                         .text,
-                        'target_path': self._gen_download_path(
-                            subpaths=['caches', environment, f'{cache}.json']
-                        ),
-                        'fs_write': self.fs_write,
-                    }
-                    write_file(data['snapshot'], data['target_path'], fs_write=data['fs_write'])
+                        self._gen_download_path(subpaths=['caches', environment, f'{cache}.json']),
+                        fs_write=self.fs_write,
+                    )
                 except HTTPError as e:
                     console.echo(
                         f'Ignoring {type(e).__name__} {e.response.status_code} error for Cache ({cache})'
@@ -274,30 +234,22 @@ class Backups:
         self.snapshot_data.developers = Developers(self.auth, self.org_name, None).list_developers(
             prefix=self.prefix, format='dict'
         )
-        data = {
-            'snapshot': self.snapshot_data.developers,
-            'target_path': self._gen_snapshot_path(subpaths=['developers', 'developers.json']),
-            'fs_write': self.fs_write,
-            'indent': 2,
-        }
         write_file(
-            data['snapshot'], data['target_path'], fs_write=data['fs_write'], indent=data['indent']
+            self.snapshot_data.developers,
+            self._gen_download_path(is_snapshot=True, subpaths=['developers', 'developers.json']),
+            fs_write=self.fs_write,
+            indent=2,
         )
         return self.snapshot_data.developers
 
     def download_developers(self):
         for developer in self.snapshot_data.developers:
             try:
-                data = {
-                    'snapshot': Developers(self.auth, self.org_name, developer)
-                    .get_developer()
-                    .text,
-                    'target_path': self._gen_download_path(
-                        subpaths=['developers', f'{developer}.json']
-                    ),
-                    'fs_write': self.fs_write,
-                }
-                write_file(data['snapshot'], data['target_path'], fs_write=data['fs_write'])
+                write_file(
+                    Developers(self.auth, self.org_name, developer).get_developer().text,
+                    self._gen_download_path(subpaths=['developers', f'{developer}.json']),
+                    fs_write=self.fs_write,
+                )
             except HTTPError as e:
                 console.echo(
                     f'Ignoring {type(e).__name__} {e.response.status_code} error for Developer ({developer})'
@@ -309,30 +261,22 @@ class Backups:
         self.snapshot_data.apiproducts = Apiproducts(
             self.auth, self.org_name, None
         ).list_api_products(prefix=self.prefix, format='dict')
-        data = {
-            'snapshot': self.snapshot_data.apiproducts,
-            'target_path': self._gen_snapshot_path(subpaths=['apiproducts', 'apiproducts.json']),
-            'fs_write': self.fs_write,
-            'indent': 2,
-        }
         write_file(
-            data['snapshot'], data['target_path'], fs_write=data['fs_write'], indent=data['indent']
+            self.snapshot_data.apiproducts,
+            self._gen_download_path(is_snapshot=True, subpaths=['apiproducts', 'apiproducts.json']),
+            fs_write=self.fs_write,
+            indent=2,
         )
         return self.snapshot_data.apiproducts
 
     def download_apiproducts(self):
         for apiproduct in self.snapshot_data.apiproducts:
             try:
-                data = {
-                    'snapshot': Apiproducts(self.auth, self.org_name, apiproduct)
-                    .get_api_product()
-                    .text,
-                    'target_path': self._gen_download_path(
-                        subpaths=['apiproducts', f'{apiproduct}.json']
-                    ),
-                    'fs_write': self.fs_write,
-                }
-                write_file(data['snapshot'], data['target_path'], fs_write=data['fs_write'])
+                write_file(
+                    Apiproducts(self.auth, self.org_name, apiproduct).get_api_product().text,
+                    self._gen_download_path(subpaths=['apiproducts', f'{apiproduct}.json']),
+                    fs_write=self.fs_write,
+                )
             except HTTPError as e:
                 console.echo(
                     f'Ignoring {type(e).__name__} {e.response.status_code} error for API Product ({apiproduct})'
@@ -350,17 +294,11 @@ class Backups:
         )
         self.snapshot_data.apps = {k: v for k, v in self.snapshot_data.apps.items() if v}
         for app, details in self.snapshot_data.apps.items():
-            data = {
-                'snapshot': details,
-                'target_path': self._gen_snapshot_path(subpaths=['apps', f'{app}.json']),
-                'fs_write': self.fs_write,
-                'indent': 2,
-            }
             write_file(
-                data['snapshot'],
-                data['target_path'],
-                fs_write=data['fs_write'],
-                indent=data['indent'],
+                details,
+                self._gen_download_path(is_snapshot=True, subpaths=['apps', f'{app}.json']),
+                fs_write=self.fs_write,
+                indent=2,
             )
         return self.snapshot_data.apps
 
@@ -368,16 +306,13 @@ class Backups:
         for developer, apps in self.snapshot_data.apps.items():
             for app in apps:
                 try:
-                    data = {
-                        'snapshot': Apps(self.auth, self.org_name, app)
+                    write_file(
+                        Apps(self.auth, self.org_name, app)
                         .get_developer_app_details(developer)
                         .text,
-                        'target_path': self._gen_download_path(
-                            subpaths=['apps', developer, f'{app}.json']
-                        ),
-                        'fs_write': self.fs_write,
-                    }
-                    write_file(data['snapshot'], data['target_path'], fs_write=data['fs_write'])
+                        self._gen_download_path(subpaths=['apps', developer, f'{app}.json']),
+                        fs_write=self.fs_write,
+                    )
                 except HTTPError as e:
                     console.echo(
                         f'Ignoring {type(e).__name__} {e.response.status_code} error for Developer App ({app})'
@@ -393,51 +328,21 @@ class Backups:
             self.snapshot_data.userroles = [
                 role for role in self.snapshot_data.userroles if role.startswith(self.prefix)
             ]
-        data = {
-            'snapshot': self.snapshot_data.userroles,
-            'target_path': self._gen_snapshot_path(subpaths=['userroles', 'userroles.json']),
-            'fs_write': self.fs_write,
-            'indent': 2,
-        }
         write_file(
-            data['snapshot'], data['target_path'], fs_write=data['fs_write'], indent=data['indent']
+            self.snapshot_data.userroles,
+            self._gen_download_path(is_snapshot=True, subpaths=['userroles', 'userroles.json']),
+            fs_write=self.fs_write,
+            indent=2,
         )
         return self.snapshot_data.userroles
 
-    def _get_users_for_a_role(self, role_name):
-        return Userroles(self.auth, self.org_name, role_name).get_users_for_a_role().json()
-
-    @staticmethod
-    def _sort_lists_in_permissions(resource_permissions):
-        for i in range(len(resource_permissions.get('resourcePermission'))):
-            resource_permissions['resourcePermission'][i]['permissions'].sort()
-        return resource_permissions
-
-    def _get_permissions(self, role_name):
-        return json.dumps(
-            Backups._sort_lists_in_permissions(
-                Permissions(self.auth, self.org_name, role_name).get_permissions(
-                    formatted=True, format='json'
-                )
-            ),
-            indent=2,
-        )
-
     def _download_users_for_a_role(self, role_name):
         try:
-            data = {
-                'snapshot': self._get_users_for_a_role(role_name),
-                'target_path': self._gen_download_path(
-                    subpaths=['userroles', role_name, 'users.json']
-                ),
-                'fs_write': self.fs_write,
-                'indent': 2,
-            }
             write_file(
-                data['snapshot'],
-                data['target_path'],
-                fs_write=data['fs_write'],
-                indent=data['indent'],
+                Userroles(self.auth, self.org_name, role_name).get_users_for_a_role().json(),
+                self._gen_download_path(subpaths=['userroles', role_name, 'users.json']),
+                fs_write=self.fs_write,
+                indent=2,
             )
         except HTTPError as e:
             console.echo(
@@ -446,14 +351,20 @@ class Backups:
 
     def _download_resource_permissions(self, role_name):
         try:
-            data = {
-                'snapshot': self._get_permissions(role_name),
-                'target_path': self._gen_download_path(
+            write_file(
+                json.dumps(
+                    Userroles.sort_permissions(
+                        Permissions(self.auth, self.org_name, role_name).get_permissions(
+                            formatted=True, format='json'
+                        )
+                    ),
+                    indent=2,
+                ),
+                self._gen_download_path(
                     subpaths=['userroles', role_name, 'resource_permissions.json']
                 ),
-                'fs_write': self.fs_write,
-            }
-            write_file(data['snapshot'], data['target_path'], fs_write=data['fs_write'])
+                fs_write=self.fs_write,
+            )
         except HTTPError as e:
             console.echo(
                 f'Ignoring {type(e).__name__} {e.response.status_code} error for User Role ({role_name}) resource permissions'
