@@ -8,12 +8,15 @@ from requests.exceptions import HTTPError
 from apigee import (APIGEE_ADMIN_API_URL,
                     APIGEE_CLI_AUTHORIZATION_DEVELOPER_ATTRIBUTE, auth,
                     console)
+from apigee.developers.serializer import DevelopersSerializer
 
 CREATE_DEVELOPER_PATH = '{api_url}/v1/organizations/{org}/developers'
 DELETE_DEVELOPER_PATH = '{api_url}/v1/organizations/{org}/developers/{developer_email}'
 GET_DEVELOPER_PATH = '{api_url}/v1/organizations/{org}/developers/{developer_email}'
 GET_DEVELOPER_BY_APP_PATH = '{api_url}/v1/organizations/{org}/developers?app={app_name}'
-LIST_DEVELOPERS_PATH = '{api_url}/v1/organizations/{org}/developers?expand={expand}&count={count}&startKey={startkey}'
+LIST_DEVELOPERS_PATH = (
+    '{api_url}/v1/organizations/{org}/developers?expand={expand}&count={count}&startKey={startkey}'
+)
 SET_DEVELOPER_STATUS_PATH = (
     '{api_url}/v1/organizations/{org}/developers/{developer_email}?action={action}'
 )
@@ -35,27 +38,6 @@ UPDATE_ALL_DEVELOPER_ATTRIBUTES_PATH = (
 )
 
 
-class DevelopersSerializer:
-    def serialize_details(self, developers, format, prefix=None):
-        resp = developers
-        if format == 'text':
-            return developers.text
-        developers = developers.json()
-        if prefix:
-            developers = [
-                developer for developer in developers if developer.startswith(prefix)
-            ]
-        if format == 'json':
-            return json.dumps(developers)
-        elif format == 'table':
-            pass
-        elif format == 'dict':
-            return developers
-        # else:
-        #     raise ValueError(format)
-        return resp
-
-
 class Developers:
     def __init__(self, auth, org_name, developer_email):
         self._auth = auth
@@ -89,13 +71,10 @@ class Developers:
     def __call__(self):
         pass
 
-    def create_developer(
-        self, first_name, last_name, user_name, attributes='{"attributes" : [ ]}'
-    ):
+    def create_developer(self, first_name, last_name, user_name, attributes='{"attributes" : [ ]}'):
         uri = CREATE_DEVELOPER_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name)
         hdrs = auth.set_header(
-            self._auth,
-            headers={'Accept': 'application/json', 'Content-Type': 'application/json'},
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'}
         )
         body = {
             'email': self._developer_email,
@@ -110,9 +89,7 @@ class Developers:
 
     def delete_developer(self):
         uri = DELETE_DEVELOPER_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            developer_email=self._developer_email,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer_email=self._developer_email
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
@@ -121,9 +98,7 @@ class Developers:
 
     def get_developer(self):
         uri = GET_DEVELOPER_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            developer_email=self._developer_email,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer_email=self._developer_email
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
@@ -139,9 +114,7 @@ class Developers:
         resp.raise_for_status()
         return resp
 
-    def list_developers(
-        self, prefix=None, expand=False, count=1000, startkey="", format='json'
-    ):
+    def list_developers(self, prefix=None, expand=False, count=1000, startkey="", format='json'):
         uri = LIST_DEVELOPERS_PATH.format(
             api_url=APIGEE_ADMIN_API_URL,
             org=self._org_name,
@@ -171,13 +144,10 @@ class Developers:
 
     def update_developer(self, request_body):
         uri = UPDATE_DEVELOPER_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            developer_email=self._developer_email,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer_email=self._developer_email
         )
         hdrs = auth.set_header(
-            self._auth,
-            headers={'Accept': 'application/json', 'Content-Type': 'application/json'},
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'}
         )
         body = json.loads(request_body)
         resp = requests.put(uri, headers=hdrs, json=body)
@@ -223,9 +193,7 @@ class Developers:
 
     def get_all_developer_attributes(self):
         uri = GET_ALL_DEVELOPER_ATTRIBUTES_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            developer_email=self._developer_email,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer_email=self._developer_email
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
@@ -234,13 +202,10 @@ class Developers:
 
     def update_all_developer_attributes(self, request_body):
         uri = UPDATE_ALL_DEVELOPER_ATTRIBUTES_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            developer_email=self._developer_email,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer_email=self._developer_email
         )
         hdrs = auth.set_header(
-            self._auth,
-            headers={'Accept': 'application/json', 'Content-Type': 'application/json'},
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'}
         )
         body = json.loads(request_body)
         resp = requests.post(uri, headers=hdrs, json=body)
